@@ -1,6 +1,6 @@
 use 5.020;
 package Pg::BulkLoad;
-$Pg::BulkLoad::VERSION = '2.03';
+$Pg::BulkLoad::VERSION = '2.031';
 use feature qw/signatures postderef/;
 no warnings qw/experimental uninitialized/;
 use Try::Tiny;
@@ -97,7 +97,7 @@ Pg::BulkLoad - Bulk Load for Postgres with ability to skip bad records.
 
 =head1 VERSION
 
-version 2.03
+version 2.031
 
 =head1 Pg::BulkLoad
 
@@ -112,13 +112,11 @@ Load Comma and Tab Delimited files into Postgres, skipping bad records.
 
  use Pg::BulkCopy;
 
- my %args = (
-	pg => DBI->connect("dbi:Pg:dbname=$dbname", '', '', {AutoCommit => 0}),
+ my $pgc = Pg::BulkLoad->new(  
+ 	pg => DBI->connect("dbi:Pg:dbname=$dbname", '', '', {AutoCommit => 0}),
 	errorfile => '/tmp/pgbulk.error',
 	errorlimit => 500,
-	);
-
- my $pgc = Pg::BulkLoad->new(  %args );
+ );
 
  .... # your code to read file names and possibly manipulate files contents prior to load.
 
@@ -128,12 +126,10 @@ Load Comma and Tab Delimited files into Postgres, skipping bad records.
 
 =head2 new 
 
-Takes arguments in has format:
+Takes arguments in hash format:
 
  pg => DBD::Pg database_handle (mandatory),
-
  errorfile => A file to log errors to (mandatory),
-
  errorcount => a limit of errors before giving up (optional)
 
 =head2 load ($file, $table, $format )
